@@ -12,7 +12,7 @@ Example:
 >>> test1.delete()  # dangerous!
 '''
 
-__version__      = '0.1'
+__version__      = '0.2'
 __author__       = 'Volker Grabsch'
 __author_email__ = 'vog@notjusthosting.com'
 __url__          = 'http://www.profv.de/python-vserver/'
@@ -389,10 +389,10 @@ class DebianVServer(object):
             self.p.run([u'chpasswd'], input=(u'%s:%s\n' % (user, password)))
 
     # zope
-    def add_zope_instance(self, version, user, admin_password):
+    def add_zope_instance(self, version, user, zope_user, zope_password):
         self.p.run([u'su', u'-', user, u'-c',
                     u"dzhandle -z'%s' make-instance default -m manual -u '%s:%s'"
-                    % (version, u'admin', admin_password)])
+                    % (version, zope_user, zope_password)])
 
     # vserver
     running = parent_property(u'running')
@@ -453,7 +453,7 @@ class HostingVServer(object):
             self.p.ssh_host_keys = keys_vserver.p.ssh_host_keys
         self.p.start_service(u'ssh')
 
-    def install_zope2(self, user, password, admin_password):
+    def install_zope2(self, user, password, zope_user, zope_password):
         self.p.install(
             u'python-4suite',
             u'python-egenix-mxdatetime',
@@ -499,7 +499,7 @@ esac
 ''')
         self.p.add_user(user)
         self.p.set_user_password(user, password)
-        self.p.add_zope_instance(u'2.10', user, admin_password)
+        self.p.add_zope_instance(u'2.10', user, zope_user, zope_password)
         self.p.start_service(u'zope-users')
 
 def _test():
